@@ -3,20 +3,22 @@ import atexit
 from uuid import uuid4
 from functools import lru_cache
 
-from .SIMULTAN.Project.Services import *
-from .SIMULTAN.Project.ProjectData import *
-from .SIMULTAN.Project.ProjectLoaders import *
-from .SIMULTAN.UI.Services import *
-from .SIMULTAN.DataExchange import *
+from .SIMULTAN.Project.Services import IAuthenticationService
+from .SIMULTAN.Project.ProjectData import ProjectDataManager
+from .SIMULTAN.Project.ProjectLoaders import ZipProjectIO
+from .SIMULTAN.UI.Services import ServicesProvider
+from .SIMULTAN.DataExchange import ComponentGeometryExchange
 from .ParameterStructure.Component import ComponentManagerType
 from .ParameterStructure.Users import *
-from .GeometryViewer import *
-from .GeometryViewer.Service import *
+from .GeometryViewer import TemporaryGeometryViewerInstance
+from .GeometryViewer.Service import GeometryViewerService
 from .GeometryViewer.Model import *
-from .GeometryViewer.IO import *
+from .GeometryViewer.IO import SimGeoIO
 from System.Security import SecureString
 from System.IO import FileInfo
 
+from System import ArgumentOutOfRangeException
+
 # from .utils import *
 # from .geo_default_types import *
 
@@ -97,10 +99,17 @@ class DataModel:
                     continue
 
                 file_info = FileInfo(resource.CurrentFullPath)
+
                 if file_info.Extension == '.simgeo':
                     model = SimGeoIO.Load(file_info, self.inst, self.serv)
                     self.models_dict[resource.Key] = model
-                    self.serv.AddGeometryModel(model)
+                    try:
+                        self.serv.AddGeometryModel(model)
+                    except ArgumentOutOfRangeException as e:
+                        logger.warning(f'Error while loading Model: {model} from {model.File}: {e}. Trying reload...')
+                        model = SimGeoIO.Load(file_info, self.inst, self.serv)
+                        self.models_dict[resource.Key] = model
+                        self.serv.AddGeometryModel(model)
 
         self.ValueFields = self.project_data_manager.ValueManager.Items
         self.import_data_model()
