@@ -7,13 +7,15 @@ from uuid import uuid4
 from collections import UserList
 from .default_types import SimultanObject
 from .default_types import List as SimultanList
-from .default_types import ValueField, BuildInFace, BuildInVolume, BuildInZone
+from .default_types import ValueField, BuildInFace, BuildInVolume, BuildInZone, BaseBuildInConstruction, BuildInMaterialLayer
 from .geo_default_types import geometry_types
 from .geometry import GeometryModel
 
 from functools import lru_cache
 
+from System.Linq import Enumerable
 from ParameterStructure.Values import SimMultiValuePointer
+from .ParameterStructure.Component import Component
 
 
 logger = colorlog.getLogger('PySimultan')
@@ -182,7 +184,9 @@ class TemplateParser(object):
              'Geometrische_Flächen': BuildInFace,
              'Geometric Volume': BuildInVolume,
              'Geometrische_Volumina': BuildInVolume,
-             'BuildInZone': BuildInZone}
+             'BuildInZone': BuildInZone,
+             'BuildInConstruction': BaseBuildInConstruction,
+             'BuildInMaterialLayer': BuildInMaterialLayer}
 
     geo_bases = {'base': geometry_types.base,
                  'layer': geometry_types.layer,
@@ -289,12 +293,14 @@ class TemplateParser(object):
         logger.info('template-class creation finished\n\n')
 
     @lru_cache(maxsize=None)
-    def create_python_object(self, component):
+    def create_python_object(self, component, template_name=None):
 
         # get the template or slot
-        template_name = None
+        # template_name = None
         if hasattr(component, 'ContainedParameters'):
-            template_name = next((x.TextValue for x in component.ContainedParameters.Items if x.Name == 'TYPE'), None)
+            t_name = next((x.TextValue for x in component.ContainedParameters.Items if x.Name == 'TYPE'), None)
+            if t_name is not None:
+                template_name = t_name
 
         if (template_name is None) and (hasattr(component, 'get_CurrentSlot')):
             template_name = component.FitsInSlots[0]
@@ -353,11 +359,15 @@ class TemplateParser(object):
             if model is None:
                 typed_models_dict[key] = None
                 continue
-            typed_models_dict[key] = GeometryModel(wrapped_obj=model,
+            typed_models_dict[key] = GeometryModel(template_parser=self,
+                                                   wrapped_obj=model,
                                                    geo_types=self.geo_bases)
             # models.append(GeometryModel(wrapped_obj=model))
         return typed_models_dict
 
+    def get_geo_components(self, geometry):
+        return Enumerable.ToList[Component](self.current_data_model.exch.GetComponents(geometry))
+
 
 def add_properties(prop, type):
     """
